ChangeMembers

Enum ChangeMembers 

pub enum ChangeMembers<NID, N>
where NID: NodeId, N: Node,
{ AddVoterIds(BTreeSet<NID>), AddVoters(BTreeMap<NID, N>), RemoveVoters(BTreeSet<NID>), ReplaceAllVoters(BTreeSet<NID>), AddNodes(BTreeMap<NID, N>), SetNodes(BTreeMap<NID, N>), RemoveNodes(BTreeSet<NID>), ReplaceAllNodes(BTreeMap<NID, N>), }
Defines various actions to change the membership, including adding or removing learners or voters.

Variants



AddVoterIds(BTreeSet<NID>)

Upgrade learners to voters.

The learners have to present or error::LearnerNotFound error will be returned.



AddVoters(BTreeMap<NID, N>)

Add voters with corresponding nodes.



RemoveVoters(BTreeSet<NID>)

Remove voters, leave removed voters as learner or not.



ReplaceAllVoters(BTreeSet<NID>)

Replace voter ids with a new set. The node of every new voter has to already be a learner.



AddNodes(BTreeMap<NID, N>)

Add nodes to membership, as learners.

it WONT replace existing node.

Prefer using this variant instead of SetNodes whenever possible, as AddNodes ensures safety, whereas incorrect usage of SetNodes can result in a brain split. See: Update-Node



SetNodes(BTreeMap<NID, N>)

Add or replace nodes in membership config.

it WILL replace existing node.

Prefer using AddNodes instead of SetNodes whenever possible, as AddNodes ensures safety, whereas incorrect usage of SetNodes can result in a brain split. See: Update-Node



RemoveNodes(BTreeSet<NID>)

Remove nodes from membership.

If a node is still a voter, it returns error::LearnerNotFound error.



ReplaceAllNodes(BTreeMap<NID, N>)

Replace all nodes with a new set.

Every voter has to have a corresponding node in the new set, otherwise it returns error::LearnerNotFound error.