pub enum StorageError<NID>where
NID: NodeId,{
Defensive {
source: DefensiveError<NID>,
},
IO {
source: StorageIOError<NID>,
},
}Expand description
A storage error could be either a defensive check error or an error occurred when doing the actual io operation.
It indicates a data crash. An application returning this error will shutdown the Openraft node immediately to prevent further damage.
Variants
Defensive
An error raised by defensive check.
Fields

source: DefensiveError<NID>IO
An error raised by io operation.
Fields

source: StorageIOError<NID>Implementations
Sourceimpl<NID> StorageError<NID>where
NID: NodeId,
impl<NID> StorageError<NID>where
NID: NodeId,
pub fn into_defensive(self) -> Option<DefensiveError<NID>>
pub fn into_io(self) -> Option<StorageIOError<NID>>
pub fn from_io_error( subject: ErrorSubject<NID>, verb: ErrorVerb, io_error: Error, ) -> StorageError<NID>