pub enum StreamingError<C, E = Infallible>where
C: RaftTypeConfig,
E: Error,{
Closed(ReplicationClosed),
StorageError(StorageError<<C as RaftTypeConfig>::NodeId>),
Timeout(Timeout<<C as RaftTypeConfig>::NodeId>),
Unreachable(Unreachable),
Network(NetworkError),
RemoteError(RemoteError<<C as RaftTypeConfig>::NodeId, <C as RaftTypeConfig>::Node, E>),
}Expand description
Error occurred when streaming local data to a remote raft node.
Thus this error includes storage error, network error, and remote error.
Variants
Closed(ReplicationClosed)
The replication stream is closed intentionally.
StorageError(StorageError<<C as RaftTypeConfig>::NodeId>)
Storage error occurs when reading local data.
Timeout(Timeout<<C as RaftTypeConfig>::NodeId>)
Timeout when streaming data to remote node.
Unreachable(Unreachable)
The node is temporarily unreachable and should backoff before retrying.
Network(NetworkError)
Failed to send the RPC request and should retry immediately.
RemoteError(RemoteError<<C as RaftTypeConfig>::NodeId, <C as RaftTypeConfig>::Node, E>)
Remote node returns an error.