pub struct NetworkError { /* private fields */ }Expand description
Error that indicates a temporary network error and when it is returned, Openraft will retry immediately.
Unlike Unreachable, which indicates a error that should backoff before retrying.
Implementations
Sourceimpl NetworkError
impl NetworkError
pub fn new<E>(e: &E) -> NetworkErrorwhere
E: Error + 'static,