pub struct PayloadTooLarge { /* private fields */ }Expand description
Error indicating that an RPC is too large and cannot be sent.
This is a retryable error:
A RaftNetwork implementation returns this error to inform Openraft to divide an
AppendEntriesRequest into smaller chunks.
Openraft will immediately retry sending in smaller chunks.
If the request cannot be divided(contains only one entry), Openraft interprets it as
Unreachable.
A hint can be provided to help Openraft in splitting the request.
The application should also set an appropriate value for Config::max_payload_entries to
avoid returning this error if possible.
Example:
impl<C: RaftTypeConfig> RaftNetwork<C> for MyNetwork {
fn append_entries(&self,
rpc: AppendEntriesRequest<C>,
option: RPCOption
) -> Result<_, RPCError<C::NodeId, C::Node, RaftError<C::NodeId>>> {
if rpc.entries.len() > 10 {
return Err(PayloadTooLarge::new_entries_hint(10).into());
}
// ...
}
}Implementations
Sourceimpl PayloadTooLarge
impl PayloadTooLarge
Sourcepub fn new_entries_hint(entries_hint: u64) -> PayloadTooLarge
pub fn new_entries_hint(entries_hint: u64) -> PayloadTooLarge
Create a new PayloadTooLarge, with entries hint, without the causing error.
Sourcepub fn with_source_error(self, e: &(impl Error + 'static)) -> PayloadTooLarge
pub fn with_source_error(self, e: &(impl Error + 'static)) -> PayloadTooLarge
Set the source error that causes this PayloadTooLarge error.
pub fn action(&self) -> RPCTypes
Sourcepub fn entries_hint(&self) -> u64
pub fn entries_hint(&self) -> u64
Get the hint for entries number.