pub struct QuorumNotEnough<NID>where
NID: NodeId,{
pub cluster: String,
pub got: BTreeSet<NID>,
}Fields
cluster: Stringgot: BTreeSet<NID>Trait Implementations
Sourceimpl<NID> Clone for QuorumNotEnough<NID>
impl<NID> Clone for QuorumNotEnough<NID>
Sourcefn clone(&self) -> QuorumNotEnough<NID>
fn clone(&self) -> QuorumNotEnough<NID>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<NID> Debug for QuorumNotEnough<NID>
impl<NID> Debug for QuorumNotEnough<NID>
Sourceimpl<'de, NID> Deserialize<'de> for QuorumNotEnough<NID>where
NID: NodeId,
impl<'de, NID> Deserialize<'de> for QuorumNotEnough<NID>where
NID: NodeId,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<QuorumNotEnough<NID>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<QuorumNotEnough<NID>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<NID> Display for QuorumNotEnough<NID>
impl<NID> Display for QuorumNotEnough<NID>
impl<NID> Eq for QuorumNotEnough<NID>
Sourceimpl<NID> Error for QuorumNotEnough<NID>
impl<NID> Error for QuorumNotEnough<NID>
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl<NID, N> From<QuorumNotEnough<NID>> for CheckIsLeaderError<NID, N>
impl<NID, N> From<QuorumNotEnough<NID>> for CheckIsLeaderError<NID, N>
Sourcefn from(source: QuorumNotEnough<NID>) -> CheckIsLeaderError<NID, N>
fn from(source: QuorumNotEnough<NID>) -> CheckIsLeaderError<NID, N>
Converts to this type from the input type.
Sourceimpl<NID> PartialEq for QuorumNotEnough<NID>
impl<NID> PartialEq for QuorumNotEnough<NID>
Sourcefn eq(&self, other: &QuorumNotEnough<NID>) -> bool
fn eq(&self, other: &QuorumNotEnough<NID>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<NID> Serialize for QuorumNotEnough<NID>where
NID: NodeId,
impl<NID> Serialize for QuorumNotEnough<NID>where
NID: NodeId,
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<NID> StructuralPartialEq for QuorumNotEnough<NID>where
NID: NodeId,
Sourceimpl<NID, N> TryFrom<CheckIsLeaderError<NID, N>> for QuorumNotEnough<NID>
impl<NID, N> TryFrom<CheckIsLeaderError<NID, N>> for QuorumNotEnough<NID>
Sourcetype Error = TryIntoError<CheckIsLeaderError<NID, N>>
type Error = TryIntoError<CheckIsLeaderError<NID, N>>
The type returned in the event of a conversion error.
Sourcefn try_from(
value: CheckIsLeaderError<NID, N>,
) -> Result<QuorumNotEnough<NID>, <QuorumNotEnough<NID> as TryFrom<CheckIsLeaderError<NID, N>>>::Error>
fn try_from( value: CheckIsLeaderError<NID, N>, ) -> Result<QuorumNotEnough<NID>, <QuorumNotEnough<NID> as TryFrom<CheckIsLeaderError<NID, N>>>::Error>
Performs the conversion.