pub struct LogApplied<C>where
C: RaftTypeConfig,{ /* private fields */ }Expand description
A oneshot callback for completion of applying logs to state machine.
Implementations
Sourceimpl<C> LogApplied<C>where
C: RaftTypeConfig,
impl<C> LogApplied<C>where
C: RaftTypeConfig,
Sourcepub fn completed(
self,
result: Result<Vec<<C as RaftTypeConfig>::R>, StorageIOError<<C as RaftTypeConfig>::NodeId>>,
)
pub fn completed( self, result: Result<Vec<<C as RaftTypeConfig>::R>, StorageIOError<<C as RaftTypeConfig>::NodeId>>, )
Report apply io completion event.
It will be called when the log is successfully applied to the state machine or an error occurs.