pub struct DefensiveError<NID>where
NID: NodeId,{
pub subject: ErrorSubject<NID>,
pub violation: Violation<NID>,
pub backtrace: Option<String>,
}Expand description
An error that occurs when the RaftStore impl runs defensive check of input or output. E.g. re-applying an log entry is a violation that may be a potential bug.
Fields
subject: ErrorSubject<NID>The subject that violates store defensive check, e.g. hard-state, log or state machine.
violation: Violation<NID>The description of the violation.
backtrace: Option<String>Implementations
Sourceimpl<NID> DefensiveError<NID>where
NID: NodeId,
impl<NID> DefensiveError<NID>where
NID: NodeId,
pub fn new( subject: ErrorSubject<NID>, violation: Violation<NID>, ) -> DefensiveError<NID>