LogId

Struct LogId 

pub struct LogId<NID>
where NID: NodeId,
{ pub leader_id: LeaderId<NID>, pub index: u64, }
The identity of a raft log.

The log id serves as unique identifier for a log entry across the system. It is composed of two parts: a leader id, which refers to the leader that proposed this log, and an integer index.

Fields

leader_id: LeaderId<NID>

The id of the leader that proposed this log

index: u64

The index of a log in the storage.

Log index is a consecutive integer.

Implementations

Source

impl<NID> LogId<NID>
where NID: NodeId,

pub fn new(leader_id: LeaderId<NID>, index: u64) -> LogId<NID>

Creates a log id proposed by a committed leader with leader_id at the given index.

pub fn committed_leader_id(&self) -> &LeaderId<NID>

Returns the leader id that proposed this log.