pub struct LogState<C>where
C: RaftTypeConfig,{
pub last_purged_log_id: Option<LogId<<C as RaftTypeConfig>::NodeId>>,
pub last_log_id: Option<LogId<<C as RaftTypeConfig>::NodeId>>,
}Expand description
The state about logs.
Invariance: last_purged_log_id <= last_applied <= last_log_id
Fields
last_purged_log_id: Option<LogId<<C as RaftTypeConfig>::NodeId>>The greatest log id that has been purged after being applied to state machine.
last_log_id: Option<LogId<<C as RaftTypeConfig>::NodeId>>The log id of the last present entry if there are any entries.
Otherwise the same value as last_purged_log_id.