pub struct SnapshotMeta<NID, N>{
pub last_log_id: Option<LogId<NID>>,
pub last_membership: StoredMembership<NID, N>,
pub snapshot_id: String,
}Expand description
The metadata of a snapshot.
Including the last log id that included in this snapshot, the last membership included, and a snapshot id.
Fields
last_log_id: Option<LogId<NID>>Log entries upto which this snapshot includes, inclusive.
last_membership: StoredMembership<NID, N>The last applied membership config.
snapshot_id: StringTo identify a snapshot when transferring.
Caveat: even when two snapshot is built with the same last_log_id, they still could be
different in bytes.
Implementations
Sourceimpl<NID, N> SnapshotMeta<NID, N>
impl<NID, N> SnapshotMeta<NID, N>
pub fn signature(&self) -> SnapshotSignature<NID>
Sourcepub fn last_log_id(&self) -> Option<&LogId<NID>>
pub fn last_log_id(&self) -> Option<&LogId<NID>>
Returns a ref to the id of the last log that is included in this snasphot.