pub struct TypeConfig {}Trait Implementations
Sourceimpl Clone for TypeConfig
impl Clone for TypeConfig
Sourcefn clone(&self) -> TypeConfig
fn clone(&self) -> TypeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TypeConfig
Sourceimpl Debug for TypeConfig
impl Debug for TypeConfig
Sourceimpl Default for TypeConfig
impl Default for TypeConfig
Sourcefn default() -> TypeConfig
fn default() -> TypeConfig
Returns the “default value” for a type. Read more
impl Eq for TypeConfig
Sourceimpl Ord for TypeConfig
impl Ord for TypeConfig
Sourcefn cmp(&self, other: &TypeConfig) -> Ordering
fn cmp(&self, other: &TypeConfig) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TypeConfig
impl PartialEq for TypeConfig
Sourcefn eq(&self, other: &TypeConfig) -> bool
fn eq(&self, other: &TypeConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TypeConfig
impl PartialOrd for TypeConfig
Sourceimpl RaftTypeConfig for TypeConfig
impl RaftTypeConfig for TypeConfig
Sourcetype Entry = Entry<TypeConfig>
type Entry = Entry<TypeConfig>
Raft log entry, which can be built from an AppData.
Sourcetype SnapshotData = Cursor<Vec<u8>>
type SnapshotData = Cursor<Vec<u8>>
Snapshot data for exposing a snapshot for reading & writing. Read more
Sourcetype Responder = OneshotResponder<TypeConfig>
type Responder = OneshotResponder<TypeConfig>
Send the response or error of a client write request(
WriteResult). Read moreSourcetype AsyncRuntime = TokioRuntime
type AsyncRuntime = TokioRuntime
Asynchronous runtime type.
impl StructuralPartialEq for TypeConfig