pub enum RaftError<NID, E = Infallible>where
NID: NodeId,{
APIError(E),
Fatal(Fatal<NID>),
}Expand description
RaftError is returned by API methods of Raft.
It is either a Fatal error indicating that Raft is no longer running, such as underlying IO
error, or an API error E.
Variants
Implementations
Sourceimpl<NID, E> RaftError<NID, E>
impl<NID, E> RaftError<NID, E>
Sourcepub fn into_api_error(self) -> Option<E>
pub fn into_api_error(self) -> Option<E>
Try to convert self to APIError.
Sourcepub fn into_fatal(self) -> Option<Fatal<NID>>
pub fn into_fatal(self) -> Option<Fatal<NID>>
Try to convert self to Fatal error.
Sourcepub fn forward_to_leader<N>(&self) -> Option<&ForwardToLeader<NID, N>>
pub fn forward_to_leader<N>(&self) -> Option<&ForwardToLeader<NID, N>>
Return a reference to ForwardToLeader if Self::APIError contains it.
Sourcepub fn into_forward_to_leader<N>(self) -> Option<ForwardToLeader<NID, N>>
pub fn into_forward_to_leader<N>(self) -> Option<ForwardToLeader<NID, N>>
Try to convert self to ForwardToLeader error if APIError is a ForwardToLeader error.