StorageHelper

Struct StorageHelper 

pub struct StorageHelper<'a, C, LS, SM>{ /* private fields */ }
StorageHelper provides additional methods to access a RaftLogStorage and RaftStateMachine implementation.

Implementations

Source

impl<'a, C, LS, SM> StorageHelper<'a, C, LS, SM>

pub fn new(sto: &'a mut LS, sm: &'a mut SM) -> StorageHelper<'a, C, LS, SM>

Creates a new StorageHelper that provides additional functions based on the underlying RaftLogStorage and RaftStateMachine implementation.

pub async fn get_initial_state( &mut self, ) -> Result<RaftState<<C as RaftTypeConfig>::NodeId, <C as RaftTypeConfig>::Node, <<C as RaftTypeConfig>::AsyncRuntime as AsyncRuntime>::Instant>, StorageError<<C as RaftTypeConfig>::NodeId>>

Get Raft’s state information from storage.

When the Raft node is first started, it will call this interface to fetch the last known state from stable storage.

pub async fn get_membership( &mut self, ) -> Result<MembershipState<<C as RaftTypeConfig>::NodeId, <C as RaftTypeConfig>::Node>, StorageError<<C as RaftTypeConfig>::NodeId>>

Returns the last 2 membership config found in log or state machine.

A raft node needs to store at most 2 membership config log:

  • The first one must be committed, because raft allows to propose new membership only when the previous one is committed.
  • The second may be committed or not.

Because when handling append-entries RPC, (1) a raft follower will delete logs that are inconsistent with the leader, and (2) a membership will take effect at once it is written, a follower needs to revert the effective membership to a previous one.

And because (3) there is at most one outstanding, uncommitted membership log, a follower only need to revert at most one membership log.

Thus a raft node will only need to store at most two recent membership logs.

pub async fn last_membership_in_log( &mut self, since_index: u64, ) -> Result<Vec<StoredMembership<<C as RaftTypeConfig>::NodeId, <C as RaftTypeConfig>::Node>>, StorageError<<C as RaftTypeConfig>::NodeId>>

Get the last 2 membership configs found in the log.

This method returns at most membership logs with greatest log index which is >=since_index. If no such membership log is found, it returns None, e.g., when logs are cleaned after being applied.